"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports.InstrumentWalker = void 0;

var _solidityParserAntlr = _interopRequireDefault(require("solidity-parser-antlr"));

class InstrumentWalker {
  constructor(instrumenter) {
    this.instrumenter = instrumenter;
    this.blockStack = void 0;
    this.blockStack = [];
  }

  blockTail() {
    return this.blockStack[this.blockStack.length - 1];
  }

  walk(ast) {
    _solidityParserAntlr.default.visit(ast, {
      "Block": node => {
        this.blockStack.push(node);
      },
      "Block:exit": node => {
        this.blockStack.pop();
      },
      "BreakStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "ContinueStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "ContractDefinition": node => {
        this.instrumenter.instrumentContractDefinition(node);
      },
      "EmitStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "ExpressionStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "FunctionDefinition": node => {
        this.instrumenter.instrumentFunction(node);
      },
      "IfStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
        this.instrumenter.instrumentIfStatement(node);
      },
      "ReturnStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "ThrowStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "VariableDeclarationStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      },
      "WhileStatement": node => {
        this.instrumenter.instrumentStatement(node, this.blockTail());
      }
    });
  }

}

exports.InstrumentWalker = InstrumentWalker;
//# sourceMappingURL=instrumentWalker.js.map